<?php

/**
 * @file
 *   Handles admin pages for the Facebook-style Links module.
 */

/**
 * Settings form.
 */
function facebook_link_admin($form_state) {
  $form = array();
  $yesno = array(1 => t('Yes'), 0 => t('No'));
  
  $len_opts = drupal_map_assoc(array(10, 15, 20, 30, 40, 50, 60, 70, 80, 90, 100, 200, 300, 400, 500, 750, 1000));
  $form['facebook_link_ignore_sdefault'] = array(
    '#type' => 'checkbox',
    '#title' => t('Ignore default text'),
    '#default_value' => variable_get('facebook_link_ignore_sdefault', 0),
    '#description' => t('You can set the status update box to contain default text -- usually the previous status.')
      .' '. t('If you enable this setting, statuses saved with this default text will be saved as if the status text was blank.')
      .' '. t('This only applies when the relevant status has a link attachment.'),
  );
  $form['facebook_link_max_title_length'] = array(
    '#type' => 'select',
    '#options' => $len_opts,
    '#title' => t('Maximum link title length'),
    '#default_value' => variable_get('facebook_link_max_title_length', 100),
    '#description' => t('This controls how many characters of the link title will be stored.'),
  );  
  $form['facebook_link_max_description_length'] = array(
    '#type' => 'select',
    '#options' => $len_opts,
    '#title' => t('Maximum link description length'),
    '#default_value' => variable_get('facebook_link_max_description_length', 300),
    '#description' => t('This controls how many characters of the link description will be stored.'),
  );  
  $form['facebook_link_class'] = array(
    '#type' => 'textfield',
    '#title' => t("Additional link classes"),
    '#default_value' => variable_get('facebook_link_class', ''),
    '#description' => t("These are extra classes that are added to the link. Separate them with spaces (as you would in HTML)"),
  );  
  $form['facebook_link_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Width of the thumbnail'),
    '#default_value' => variable_get('facebook_link_width', 0),
    '#size' => 15,
    '#maxlength' => 10,
    '#description' => t('The width attribute of the img tag for thumbnail. Set to 0 for no restriction.'),
  );  
  $form['facebook_link_height'] = array(
    '#type' => 'textfield',
    '#title' => t('Height of the thumbnail'),
    '#default_value' => variable_get('facebook_link_height', 0),
    '#size' => 15,
    '#maxlength' => 10,
    '#description' => t('The height attribute of the img tag for thumbnail. Set to 0 for no restriction.'),
  );
  $form['advanced'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );
  $form['advanced']['facebook_link_max_imagesize'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum image size'),
    '#default_value' => variable_get('facebook_link_max_imagesize', ''),
    '#description' => t('Specify the size limit that applies to each image thumbnail. Enter a value like "512" (bytes), "80K" (kilobytes) or "50M" (megabytes) in order to restrict the allowed image size. Leave empty for no restrictions.'),
  );
  // Add "rel=nofollow."
  $form['advanced']['facebook_link_nofollow'] = array(
    '#type' => 'radios',
    '#options' => $yesno,
    '#title' => t('Spam link deterrent'),
    '#default_value' => variable_get('facebook_link_nofollow', 0),
    '#description' => t('If enabled, Drupal will add rel="nofollow" to all links, as a measure to reduce the effectiveness of spam links. Note: this will also prevent valid links from being followed by search engines, therefore it is likely most effective when enabled for anonymous users.'),
  );
  $form['advanced']['facebook_link_url_stub'] = array(
    '#type' => 'textfield',
    '#title' => t('Default for URL'),
    '#default_value' => variable_get('facebook_link_url_stub', 'http://'),
    '#description' => t('This will be used as a stub in the URL field.'),
  );
  $form['advanced']['facebook_link_cache_duration'] = array(
    '#type' => 'select',
    '#title' => t('Cache duration'),
    '#options' => drupal_map_assoc(array(0, 3600, 10800, 21600, 32400, 43200, 86400, 172800, 259200, 604800, 1209600, 2419200, 4838400, 9676800, 15724800, 31449600), 'format_interval'),
    '#default_value' => variable_get('facebook_link_cache_duration', 9676800),
    '#description' => t('The data retrieved from the link (title, description and images) will be cached for the set time period to improve performance. Set Zero (0) to disable caching.'),
  );
  $form['advanced']['facebook_link_timeout'] = array(
    '#type' => 'select',
    '#title' => t('Maximum execution time (in seconds)'),
    '#options' => drupal_map_assoc(array(3, 5, 10, 15, 20, 25, 30, 40, 50, 60)),
    '#default_value' => variable_get('facebook_link_timeout', 10),
    '#description' => t('Select the maximum amount of time to take while attaching a link.'),
  );
  
  return system_settings_form($form);
}

/**
 * Validate function for the settings form.
 */
function facebook_link_admin_validate($form, &$form_state) {
   $form_values = $form_state['values'];
  //Check that CSS class is valid.
  if (!empty($form_values['facebook_link_class']) && !preg_match('/^[a-zA-Z]+[_a-zA-Z0-9- ]*$/', $form_values['facebook_link_class'])) {
      form_set_error('facebook_link_class', t('The HTML "class" attribute can only include spaces, underscores, hyphens, and alphanumeric characters.'));
  }
  
  //Check that set height and width are valid.
  foreach (array('facebook_link_height', 'facebook_link_width') as $attr) {
    if (!empty($form_values[$attr]) && (!is_numeric($form_values[$attr]) || $form_values[$attr] != round($form_values[$attr]) || $form_values[$attr] < 0)) {
      form_set_error($attr, t('The @attribute must be a non-negative integer.', array('@attribute' => $attr)));
    }
  }
  
  //Check that set imagesize is valid
  if (!empty($form_values['advanced']['facebook_link_max_imagesize']) && !is_numeric(parse_size($form_values['advanced']['facebook_link_max_imagesize']))) {
    form_set_error('facebook_link_max_imagesize', t('The "Maximum image size" option must contain a valid value. You can either leave the text field empty or enter a string like "512" (bytes), "80K" (kilobytes) or "50M" (megabytes).'));
  }
}

